@@ -2,18 +2,27 @@
 # -*- coding: utf-8 -*-
 import re, operator, os
 try:
-    from cStringIO import StringIO
+    from StringIO import StringIO
 except ImportError:
     from io import StringIO
     xrange = range
 
 
+VERSION = (0, 2, 2)
+VERSION_TAG = None
+
+__version__ = ".".join(map(str, VERSION))
+if VERSION_TAG:
+    __version__ = "{0}-{1}".format(
+        __version__, VERSION_TAG)
+
+
 class Template:
     def __init__(self, content):
         self.content = content
         self.root_element = None
 
-    def merge(self, namespace, loader=None):
+    def render(self, namespace, loader=None):
         output = StoppableStream()
         self.merge_to(namespace, output, loader)
         return output.getvalue()
@@ -23,7 +32,8 @@ class Template:
             self.root_element = TemplateBody(self.content)
 
     def merge_to(self, namespace, fileobj, loader=None):
-        if loader is None: loader = NullLoader()
+        if loader is None:
+            loader = NullLoader()
         self.ensure_compiled()
         self.root_element.evaluate(fileobj, namespace, loader)
 
@@ -65,7 +75,7 @@ class NullLoader:
         raise self.load_text(name)
 
 
-class CachingFileLoader:
+class FileLoader:
     def __init__(self, basedir, debugging=False):
         self.basedir = basedir
         self.known_templates = {}
@@ -80,12 +90,15 @@ class CachingFileLoader:
         if self.debugging:
             print("Loading text from {0} {1}".format(self.basedir, name))
         f = open(self.filename_of(name))
-        try: return f.read()
-        finally: f.close()
+        try:
+            return f.read()
+        finally:
+            f.close()
 
     def load_template(self, name):
         if self.debugging:
             print("Loading template... {0}".format(name))
+
         mtime = os.path.getmtime(self.filename_of(name))
         if self.known_templates.get(name, None):
             template, prev_mtime = self.known_templates[name]
@@ -212,8 +225,8 @@ class _Element:
 
 
 class Text(_Element):
-    PLAIN = re.compile(r'((?:[^\\\$#]+|\\[\$#])+|\$[^!\{a-z0-9_]|\$$|#$|#[^\{\}a-zA-Z0-9#\*]+|\\.)(.*)$', re.S + re.I)
-    ESCAPED_CHAR = re.compile(r'\\([\\\$#])')
+    PLAIN = re.compile(r'((?:[^\\\@#]+|\\[\@#])+|\@[^!\{a-z0-9_]|\@@|#@|#[^\{\}a-zA-Z0-9#\*]+|\\.)(.*)$', re.S + re.I)
+    ESCAPED_CHAR = re.compile(r'\\([\\\@#])')
 
     def parse(self):
         text, = self.identity_match(self.PLAIN)
@@ -279,7 +292,7 @@ class BooleanLiteral(_Element):
 
 
 class StringLiteral(_Element):
-    STRING = re.compile(r"'((?:\\['nrbt\\\\\\$]|[^'\\])*)'(.*)", re.S)
+    STRING = re.compile(r"'((?:\\['nrbt\\\\\\@]|[^'\\])*)'(.*)", re.S)
     ESCAPED_CHAR = re.compile(r"\\([nrbt'\\])")
 
     def parse(self):
@@ -292,7 +305,7 @@ class StringLiteral(_Element):
         return self.value
 
 class InterpolatedStringLiteral(StringLiteral):
-    STRING = re.compile(r'"((?:\\["nrbt\\\\\\$]|[^"\\])*)"(.*)', re.S)
+    STRING = re.compile(r'"((?:\\["nrbt\\\\\\@]|[^"\\])*)"(.*)', re.S)
     ESCAPED_CHAR = re.compile(r'\\([nrbt"\\])')
 
     def parse(self):
@@ -472,7 +485,7 @@ class ParameterList(_Element):
 
 
 class FormalReference(_Element):
-    START = re.compile(r'\$(!?)(\{?)(.*)$', re.S)
+    START = re.compile(r'\@(!?)(\{?)(.*)$', re.S)
     CLOSING_BRACE = re.compile(r'\}(.*)$', re.S)
 
     def parse(self):
@@ -719,8 +732,8 @@ class IfDirective(_Element):
 
 
 class Assignment(_Element):
-    START = re.compile(r'\s*\(\s*\$([a-z_][a-z0-9_]*(?:\.[a-z_][a-z0-9_]*)*)\s*=\s*(.*)$', re.S + re.I)
-    END = re.compile(r'\s*\)(?:[ \t]*\r?\n)?(.*)$', re.S + re.M)
+    START = re.compile(r'\s*\@([a-z_][a-z0-9_]*(?:\.[a-z_][a-z0-9_]*)*)\s*=\s*(.*)$', re.S + re.I)
+    END = re.compile(r'\s*\:(?:[ \t]*\r?\n)?(.*)$', re.S + re.M)
 
     def parse(self):
         var_name, = self.identity_match(self.START)
@@ -740,7 +753,7 @@ class Assignment(_Element):
                 except AttributeError:
                     pass
             if look_in_dict:
-                try: 
+                try:
                     thingy = thingy[term]
                 except KeyError: thingy = None
                 except TypeError: thingy = None
@@ -750,11 +763,12 @@ class Assignment(_Element):
 
 class MacroDefinition(_Element):
     START = re.compile(r'#macro\b(.*)', re.S + re.I)
-    OPEN_PAREN = re.compile(r'[ \t]*\(\s*(.*)$', re.S)
+    OPEN_PAREN = re.compile(r'[ \t]\s*(.*)$', re.S)
     NAME = re.compile(r'\s*([a-z][a-z_0-9]*)\b(.*)', re.S + re.I)
-    CLOSE_PAREN = re.compile(r'[ \t]*\)(.*)$', re.S)
-    ARG_NAME = re.compile(r'[, \t]+\$([a-z][a-z_0-9]*)(.*)$', re.S + re.I)
-    RESERVED_NAMES = ('if', 'else', 'elseif', 'set', 'macro', 'for', 'parse', 'include', 'stop', 'end')
+    CLOSE_PAREN = re.compile(r'[ \t]*\:(.*)$', re.S)
+    ARG_NAME = re.compile(r'[, \t]+\@([a-z][a-z_0-9]*)(.*)$', re.S + re.I)
+    RESERVED_NAMES = ('if', 'else', 'elseif', 'set', 'macro',
+                      'for', 'parse', 'include', 'stop', 'end')
     def parse(self):
         self.identity_match(self.START)
         self.require_match(self.OPEN_PAREN, '(')
@@ -789,8 +803,8 @@ class MacroDefinition(_Element):
 
 class MacroCall(_Element):
     START = re.compile(r'#([a-z][a-z_0-9]*)\b(.*)', re.S + re.I)
-    OPEN_PAREN = re.compile(r'[ \t]*\(\s*(.*)$', re.S)
-    CLOSE_PAREN = re.compile(r'[ \t]*\)(.*)$', re.S)
+    OPEN_PAREN = re.compile(r'[ \t]\s*(.*)$', re.S)
+    CLOSE_PAREN = re.compile(r'[ \t]*\:(.*)$', re.S)
     SPACE_OR_COMMA = re.compile(r'[ \t]*(?:,|[ \t])[ \t]*(.*)$', re.S)
 
     def parse(self):
@@ -884,10 +898,10 @@ class SetDirective(_Element):
 
 class ForDirective(_Element):
     START = re.compile(r'#for\b(.*)$', re.S + re.I)
-    OPEN_PAREN = re.compile(r'[ \t]*\(\s*(.*)$', re.S)
+    OPEN_PAREN = re.compile(r'[ \t]\s*(.*)$', re.S)
     IN = re.compile(r'[ \t]+in[ \t]+(.*)$', re.S)
-    LOOP_VAR_NAME = re.compile(r'\$([a-z_][a-z0-9_]*)(.*)$', re.S + re.I)
-    CLOSE_PAREN = re.compile(r'[ \t]*\)(.*)$', re.S)
+    LOOP_VAR_NAME = re.compile(r'\@([a-z_][a-z0-9_]*)(.*)$', re.S + re.I)
+    CLOSE_PAREN = re.compile(r'[ \t]*\:(.*)$', re.S)
 
     def parse(self):
         ## Could be cleaner b/c syntax error if no '('
@@ -908,7 +922,7 @@ class ForDirective(_Element):
                 return
             if hasattr(iterable, 'keys'): iterable = iterable.keys()
             if not hasattr(iterable, '__getitem__'):
-                raise ValueError("value for $%s is not iterable in #for: %s" % (self.loop_var_name, iterable))
+                raise ValueError("value for @%s is not iterable in #for: %s" % (self.loop_var_name, iterable))
             for item in iterable:
                 namespace = LocalNamespace(namespace)
                 namespace['velocityCount'] = counter
